Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=pdok.nl
Index ¶
- Variables
- func AddGeneralValidationErrorsAndWarnings(wmts *WMTS, warnings *[]string, allErrs *field.ErrorList)
- type AzureCache
- type CacheMetaSize
- type HorizontalPodAutoscalerPatch
- type SourceWMS
- type StyleLegend
- type TileMatrixSet
- type WMTS
- func (in *WMTS) DeepCopy() *WMTS
- func (in *WMTS) DeepCopyInto(out *WMTS)
- func (in *WMTS) DeepCopyObject() runtime.Object
- func (w *WMTS) GetIngressRouteUrls() []smoothoperatormodel.URL
- func (w *WMTS) GetWmsUrls() []string
- func (w *WMTS) OperatorStatus() *smoothoperatormodel.OperatorStatus
- func (w *WMTS) TypedName() string
- func (w *WMTS) URL() smoothoperatormodel.URL
- func (w *WMTS) ValidateCreate(c client.Client) ([]string, error)
- func (w *WMTS) ValidateUpdate(c client.Client, wmtsOld *WMTS) ([]string, error)
- type WMTSCache
- type WMTSHealthCheck
- type WMTSLayer
- type WMTSLayerSource
- type WMTSLayerStyle
- type WMTSList
- type WMTSOptions
- type WMTSService
- type WMTSSpec
Constants ¶
This section is empty.
Variables ¶
var ( GroupVersion = schema.GroupVersion{Group: "pdok.nl", Version: "v2"} SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion} GroupKind = schema.GroupKind{Group: GroupVersion.Group, Kind: "WMTS"} AddToScheme = SchemeBuilder.AddToScheme TypeMetaWMTS = metav1.TypeMeta{ Kind: "WMTS", APIVersion: GroupVersion.String(), } )
Functions ¶
Types ¶
type AzureCache ¶
type AzureCache struct {
// The blob storage container
// +kubebuilder:validation:MinLength:=1
Container string `json:"container"`
// The blob store prefix on the container
// +kubebuilder:validation:MinLength:=1
BlobPrefix string `json:"blobPrefix"`
}
AzureCache Cache information based on the Azure Blob Store
func (*AzureCache) DeepCopy ¶
func (in *AzureCache) DeepCopy() *AzureCache
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AzureCache.
func (*AzureCache) DeepCopyInto ¶
func (in *AzureCache) DeepCopyInto(out *AzureCache)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CacheMetaSize ¶
CacheMetaSize The number of rows and columns that mapproxy retrieves at once
func (*CacheMetaSize) DeepCopy ¶
func (in *CacheMetaSize) DeepCopy() *CacheMetaSize
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CacheMetaSize.
func (*CacheMetaSize) DeepCopyInto ¶
func (in *CacheMetaSize) DeepCopyInto(out *CacheMetaSize)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type HorizontalPodAutoscalerPatch ¶
type HorizontalPodAutoscalerPatch struct {
MinReplicas *int32 `json:"minReplicas,omitempty"`
MaxReplicas *int32 `json:"maxReplicas,omitempty"`
Metrics []autoscalingv2.MetricSpec `json:"metrics,omitempty"`
Behavior *autoscalingv2.HorizontalPodAutoscalerBehavior `json:"behavior,omitempty"`
}
HorizontalPodAutoscalerPatch - copy of autoscalingv2.HorizontalPodAutoscalerSpec without ScaleTargetRef This way we don't have to specify the scaleTargetRef field in the CRD.
func (*HorizontalPodAutoscalerPatch) DeepCopy ¶
func (in *HorizontalPodAutoscalerPatch) DeepCopy() *HorizontalPodAutoscalerPatch
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new HorizontalPodAutoscalerPatch.
func (*HorizontalPodAutoscalerPatch) DeepCopyInto ¶
func (in *HorizontalPodAutoscalerPatch) DeepCopyInto(out *HorizontalPodAutoscalerPatch)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type SourceWMS ¶
type SourceWMS struct {
// The WMS url used for retrieving maps
URL smoothoperatormodel.URL `json:"url"`
// The generated images have a transparent background
// +kubebuilder:default:=true
// +kubebuilder:validation:Optional
Transparent *bool `json:"transparent,omitempty"`
// References to layer names
Layers []string `json:"layers"`
// References to style names
Styles []string `json:"styles"`
}
func (*SourceWMS) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new SourceWMS.
func (*SourceWMS) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type StyleLegend ¶
type StyleLegend struct {
// Blob key location of the style
// +kubebuilder:validation:MinLength:=1
BlobKey string `json:"blobKey"`
}
StyleLegend Legend information, now a small wrapper around a blob key
func (*StyleLegend) DeepCopy ¶
func (in *StyleLegend) DeepCopy() *StyleLegend
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new StyleLegend.
func (*StyleLegend) DeepCopyInto ¶
func (in *StyleLegend) DeepCopyInto(out *StyleLegend)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*StyleLegend) GetBlobKeyName ¶
func (s *StyleLegend) GetBlobKeyName() string
type TileMatrixSet ¶
type TileMatrixSet struct {
// The specified CRS
// +kubebuilder:validation:Pattern:="^EPSG:(28992|25831|25832|3034|3035|3857|4258|4326)"
CRS string `json:"crs"`
// +kubebuilder:validation:items:Pattern:="^[0-9]{1,2}(-[0-9]{1,2})?$"
ZoomLevels []string `json:"zoomLevels,omitempty"`
}
TileMatrixSet specifies the predefined tile matrices per CRS
func (*TileMatrixSet) DeepCopy ¶
func (in *TileMatrixSet) DeepCopy() *TileMatrixSet
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TileMatrixSet.
func (*TileMatrixSet) DeepCopyInto ¶
func (in *TileMatrixSet) DeepCopyInto(out *TileMatrixSet)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*TileMatrixSet) GetMaxZoomLevel ¶
func (t *TileMatrixSet) GetMaxZoomLevel() *int
Used for generation of capabilities
func (*TileMatrixSet) GetMinZoomLevel ¶
func (t *TileMatrixSet) GetMinZoomLevel() *int
type WMTS ¶
type WMTS struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
// Functional settings
Spec WMTSSpec `json:"spec"`
// Status set by the cluster
Status smoothoperatormodel.OperatorStatus `json:"status,omitempty"`
}
WMTS is the Schema for the wmts API
func (*WMTS) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WMTS.
func (*WMTS) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*WMTS) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*WMTS) GetIngressRouteUrls ¶
func (w *WMTS) GetIngressRouteUrls() []smoothoperatormodel.URL
func (*WMTS) GetWmsUrls ¶
func (*WMTS) OperatorStatus ¶
func (w *WMTS) OperatorStatus() *smoothoperatormodel.OperatorStatus
func (*WMTS) URL ¶
func (w *WMTS) URL() smoothoperatormodel.URL
type WMTSCache ¶
type WMTSCache struct {
// +kubebuilder:validation:Optional
MetaSize *CacheMetaSize `json:"metaSize,omitempty"`
// The azure block. At the moment it is the only cache backing option
Azure AzureCache `json:"azure"`
}
WMTSCache Information used to retrieve cached data
func (*WMTSCache) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WMTSCache.
func (*WMTSCache) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type WMTSHealthCheck ¶
type WMTSHealthCheck struct {
Querystring string `json:"querystring"`
// +kubebuilder:validation:Pattern=(image/png|text/xml|text/html)
Mimetype string `json:"mimetype"`
}
WMTSHealthCheck is the struct with all fields to configure custom healthchecks
func (*WMTSHealthCheck) DeepCopy ¶
func (in *WMTSHealthCheck) DeepCopy() *WMTSHealthCheck
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WMTSHealthCheck.
func (*WMTSHealthCheck) DeepCopyInto ¶
func (in *WMTSHealthCheck) DeepCopyInto(out *WMTSHealthCheck)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type WMTSLayer ¶
type WMTSLayer struct {
// The unique reference of the layer
// +kubebuilder:validation:MinLength:=1
Identifier string `json:"identifier"`
// The title of the layer
// +kubebuilder:validation:MinLength:=1
Title string `json:"title"`
// The abstract of the layer
// +kubebuilder:validation:MinLength:=1
Abstract string `json:"abstract"`
// Applied styles to the layer
Styles []WMTSLayerStyle `json:"styles"`
// The backing data source of the layer
Source WMTSLayerSource `json:"source"`
}
WMTSLayer describes the layer provided to the service consumer
func (*WMTSLayer) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WMTSLayer.
func (*WMTSLayer) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type WMTSLayerSource ¶
type WMTSLayerSource struct {
// A WMS as a data source
Wms SourceWMS `json:"wms"`
}
func (*WMTSLayerSource) DeepCopy ¶
func (in *WMTSLayerSource) DeepCopy() *WMTSLayerSource
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WMTSLayerSource.
func (*WMTSLayerSource) DeepCopyInto ¶
func (in *WMTSLayerSource) DeepCopyInto(out *WMTSLayerSource)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type WMTSLayerStyle ¶
type WMTSLayerStyle struct {
// The style identifier unique for the layer
// +kubebuilder:validation:MinLength:=1
Identifier string `json:"identifier"`
// Legend information
Legend StyleLegend `json:"legend"`
}
WMTSLayerStyle
func (*WMTSLayerStyle) DeepCopy ¶
func (in *WMTSLayerStyle) DeepCopy() *WMTSLayerStyle
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WMTSLayerStyle.
func (*WMTSLayerStyle) DeepCopyInto ¶
func (in *WMTSLayerStyle) DeepCopyInto(out *WMTSLayerStyle)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type WMTSList ¶
type WMTSList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []WMTS `json:"items"`
}
+kubebuilder:object:root=true
func (*WMTSList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WMTSList.
func (*WMTSList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*WMTSList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type WMTSOptions ¶
type WMTSOptions struct {
// Cached enables the pregenerated tiles from a permanent storage
// +kubebuilder:default:=true
// +kubebuilder:validation:Optional
Cached bool `json:"cached"`
// IncludeIngress dictates whether to deploy an Ingress or ensure none exists.
// +kubebuilder:default:=true
// +kubebuilder:validation:Optional
IncludeIngress bool `json:"includeIngress"`
// GetFeatureInfo adds a GetFeatureInfo endpoint
// +kubebuilder:default:=false
// +kubebuilder:validation:Optional
GetFeatureInfo bool `json:"getFeatureInfo"`
}
func (*WMTSOptions) DeepCopy ¶
func (in *WMTSOptions) DeepCopy() *WMTSOptions
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WMTSOptions.
func (*WMTSOptions) DeepCopyInto ¶
func (in *WMTSOptions) DeepCopyInto(out *WMTSOptions)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type WMTSService ¶
type WMTSService struct {
// Base url. Distinguished from an actual URL as the path can also be used as a base path for other URLs
BaseURL smoothoperatormodel.URL `json:"baseUrl"`
// Service title
// +kubebuilder:validation:MinLength:=1
Title string `json:"title"`
// Service abstract
// +kubebuilder:validation:MinLength:=1
Abstract string `json:"abstract"`
// AccessConstraints URL
// +kubebuilder:validation:Optional
// +kubebuilder:default="https://creativecommons.org/publicdomain/zero/1.0/deed.nl"
AccessConstraints *smoothoperatormodel.URL `json:"accessConstraints,omitempty"`
// Predefined tile matrices
TileMatrixSets []TileMatrixSet `json:"tileMatrixSets"`
// Queryable layers
Layers []WMTSLayer `json:"layers"`
// Backing cache layer configuration
Cache WMTSCache `json:"cache"`
}
func (*WMTSService) DeepCopy ¶
func (in *WMTSService) DeepCopy() *WMTSService
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WMTSService.
func (*WMTSService) DeepCopyInto ¶
func (in *WMTSService) DeepCopyInto(out *WMTSService)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type WMTSSpec ¶
type WMTSSpec struct {
// Boolean options
Options *WMTSOptions `json:"options,omitempty"`
// Optional lifecycle settings
Lifecycle *smoothoperatormodel.Lifecycle `json:"lifecycle,omitempty"`
// Scaling behavior
HorizontalPodAutoscalerPatch *HorizontalPodAutoscalerPatch `json:"horizontalPodAutoscalerPatch,omitempty"`
// +kubebuilder:validation:Type=object
// +kubebuilder:validation:Schemaless
// +kubebuilder:pruning:PreserveUnknownFields
// Strategic merge patch for the pod in the deployment. E.g. to patch the resources or add extra env vars.
PodSpecPatch corev1.PodSpec `json:"podSpecPatch"`
// Custom healthcheck options
HealthCheck *WMTSHealthCheck `json:"healthCheck,omitempty"`
// Alternative ingress urls
IngressRouteURLs smoothoperatormodel.IngressRouteURLs `json:"ingressRouteUrls,omitempty"`
// service configuration
Service WMTSService `json:"service"`
}
func (*WMTSSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new WMTSSpec.
func (*WMTSSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.